==> open-xchange-documents-backend_7.8.4.orig.tar.bz2: open-xchange-documents-backend-7.8.4/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/odf/properties/MapProperties.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.filter.odf.properties;

import org.json.JSONObject;
import com.openexchange.office.filter.odf.AttributesImpl;
import com.openexchange.office.filter.odf.Namespaces;
import com.openexchange.office.filter.odf.OpAttrs;
import com.openexchange.office.filter.odf.styles.NumberStyleBase;
import com.openexchange.office.filter.odf.styles.StyleBase;
import com.openexchange.office.filter.odf.styles.StyleManager;

final public class MapProperties extends StylePropertiesBase {

	public MapProperties(AttributesImpl attributesImpl) {
		super(attributesImpl);
	}

	@Override
	public void applyAttrs(StyleManager styleManager, JSONObject attrs) {
		//
	}

	@Override
	public void createAttrs(StyleManager styleManager, boolean contentAutoStyle, OpAttrs attrs) {
		// TODO Auto-generated method stub
		
	}

	public String getMapping(StyleManager styleManager, boolean contentAutoStyle, String family){
		String mappedResult = "";
        final String condition = getAttribute("style:condition");
        final String applyStyleName = getAttribute("style:apply-style-name");

        if(applyStyleName != null ) {
        	final StyleBase applyStyle = styleManager.getStyle(applyStyleName, family, contentAutoStyle);
            if(applyStyle instanceof NumberStyleBase) {
            	final String localFormat = ((NumberStyleBase)applyStyle).getFormat(styleManager, null, contentAutoStyle);
                if(condition!=null&&condition.length()>=9&&condition.startsWith("value()")) {
                    //always starts with "value()"
                    String operator2 = condition.substring(8, 9); // '=', "<>", '<', "<=", '>', ">="
                    int opLength = 1;
                    if(operator2.equals("=") || operator2.equals("<") || operator2.equals(">") ){
                        opLength = 2;
                    }
                    try{
                        double opValue = Double.parseDouble(condition.substring(7 + opLength));
                        if(opValue != 0.) {
                            mappedResult += '[';
                            mappedResult += condition.substring(7, 7 + opLength );
                            mappedResult += Double.toString(opValue);
                            mappedResult += ']';
                        }
                    } catch (NumberFormatException e) {
                        //
                    }
                }
                mappedResult += localFormat;
            }
        }
        return mappedResult;
    }

	@Override
	public String getQName() {
		return "style:map";
	}

	@Override
	public String getLocalName() {
		return "map";
	}

	@Override
	public String getNamespace() {
		return Namespaces.STYLE;
	}

	@Override
	public MapProperties clone() {
		return (MapProperties)_clone();
	}
}

==> open-xchange-documents-backend_7.10.3.orig.tar.bz2: open-xchange-documents-backend-7.10.3/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/odf/properties/MapProperties.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.filter.odf.properties;

import org.json.JSONObject;
import com.openexchange.office.filter.odf.AttributesImpl;
import com.openexchange.office.filter.odf.Namespaces;
import com.openexchange.office.filter.odf.OpAttrs;
import com.openexchange.office.filter.odf.styles.NumberStyleBase;
import com.openexchange.office.filter.odf.styles.StyleBase;
import com.openexchange.office.filter.odf.styles.StyleFamily;
import com.openexchange.office.filter.odf.styles.StyleManager;

final public class MapProperties extends StylePropertiesBase {

	public MapProperties(AttributesImpl attributesImpl) {
		super(attributesImpl);
	}

	@Override
	public void applyAttrs(StyleManager styleManager, JSONObject attrs) {
		//
	}

	@Override
	public void createAttrs(StyleManager styleManager, boolean contentAutoStyle, OpAttrs attrs) {
		// TODO Auto-generated method stub
		
	}

	public String getMapping(StyleManager styleManager, boolean contentAutoStyle, StyleFamily family){
		String mappedResult = "";
        final String condition = getAttribute("style:condition");
        final String applyStyleName = getAttribute("style:apply-style-name");

        if(applyStyleName != null ) {
        	final StyleBase applyStyle = styleManager.getStyle(applyStyleName, family, contentAutoStyle);
            if(applyStyle instanceof NumberStyleBase) {
            	final String localFormat = ((NumberStyleBase)applyStyle).getFormat(styleManager, null, contentAutoStyle);
                if(condition!=null&&condition.length()>=9&&condition.startsWith("value()")) {
                    //always starts with "value()"
                    String operator2 = condition.substring(8, 9); // '=', "<>", '<', "<=", '>', ">="
                    int opLength = 1;
                    if(operator2.equals("=") || operator2.equals("<") || operator2.equals(">") ){
                        opLength = 2;
                    }
                    try{
                        double opValue = Double.parseDouble(condition.substring(7 + opLength));
                        if(opValue != 0.) {
                            mappedResult += '[';
                            mappedResult += condition.substring(7, 7 + opLength );
                            mappedResult += Double.toString(opValue);
                            mappedResult += ']';
                        }
                    } catch (NumberFormatException e) {
                        //
                    }
                }
                mappedResult += localFormat;
            }
        }
        return mappedResult;
    }

	@Override
	public String getQName() {
		return "style:map";
	}

	@Override
	public String getLocalName() {
		return "map";
	}

	@Override
	public String getNamespace() {
		return Namespaces.STYLE;
	}

	@Override
	public MapProperties clone() {
		return (MapProperties)_clone();
	}
}
